This is Driveways by Andres Canas, Dylan Fay, Henry Parker, Zack Saadioui.

# Driveways
Driveways


## Installation from PyPI: 
- pip install driveway==0.1.4
- runmyserver 

- ***GDAL libraries must be installed on device
- $ sudo aptitude install gdal-bin libgdal-dev
- $ sudo aptitude install python3-gdal
- $ sudo aptitude install binutils libproj-dev

## Installing APK
- APK is stored under "Realeases" on GitHub
- Install APK on device after server is running 
- Tested on device running api 27 (Android 8.1 Oreo)

#Git Repo
https://github.com/andrescanas01/driveways.git

# Resources

[Simplest Git Tutorial](https://rogerdudler.github.io/git-guide/)

[Django API List](https://github.com/wsvincent/awesome-django)

[Django Tutorials](https://github.com/wsvincent/awesome-django#educational)

## API's 



[Django Calendar](https://github.com/llazzaro/django-scheduler)

[Django Map](https://github.com/madisona/django-google-maps)

[Django Forms](https://github.com/django-crispy-forms/django-crispy-forms/)

# DRIVEWAYS

-   Enter destination and be shown available driveways to park nearby
-   User can list their available parking spaces to earn extra income
-   Driveways is meant to offer private parking.

![image-20200617143552790](assets/Design-Prototype/image-20200617143552790.png)\\

## Features / Planning

#TODO: Finish Features

-   Map Functionality: Google API's
    - Object Markers
        - Price/(day,timeframe), location, time, 
-   Search Functionality
    -   address search
    -   distance function
-   **Buyer Portal**
-   **Seller Portal**
        -   Make Listing (Update DB):
            -   Cost, Time, Address
- **Sign in Page**
    -   **Account Details**
        -   Payment
        -   Account Information
    
    

Later features:

## User Testing

> Later: Todo. 
